# -*- coding: utf-8 -*-

import logging
class Logger:
    def __init__(self,file="run.log"):
        """[summary]
        快速

        Args:
            file (str, optional): [description]. 日志文件目录位置
        """
        
        logger = logging.getLogger()

        formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')

        # Setup file handler
        fhandler  = logging.FileHandler(file)
        fhandler.setLevel(logging.DEBUG)
        fhandler.setFormatter(formatter)

#         # Configure stream handler for the cells
        chandler = logging.StreamHandler()
        chandler.setLevel(logging.DEBUG)
        chandler.setFormatter(formatter)

#         # Add both handlers
        logger.addHandler(fhandler)
        logger.addHandler(chandler)
        logger.setLevel(logging.DEBUG)

        # Show the handlers
        logger.handlers
        self.logger=logger
    def add(self,text):
        """[summary]
        添加日志信息，默认采用info

        Args:
            text ([type]): [description] 日志内容
        """
        # Log Something
        self.logger.info(text)

    def info(self,text):
        """[summary]
        添加info日志信息

        Args:
            text ([type]): [description]
        """
        # Log Something
        self.logger.info(text)
    def debug(self,text):
        """[summary]
        添加debug日志信息

        Args:
            text ([type]): [description]
        """
        # Log Something
        self.logger.debug(text)
    def error(self,text):
        """[summary]
        添加error日志信息

        Args:
            text ([type]): [description]
        """
        # Log Something
        self.logger.error(text)        

# ————————————————
# 版权声明：本文为CSDN博主「农民小飞侠」的原创文章，遵循CC 4.0 BY-SA版权协议，转载请附上原文出处链接及本声明。
# 原文链接：https://blog.csdn.net/w5688414/article/details/100882268
# logger=tkitLogger()
# logger.add("dd")


# -*- coding: utf-8 -*-
from setuptools import find_packages, setup
from os import path as os_path
import time
this_directory = os_path.abspath(os_path.dirname(__file__))
"""帮助[https://www.notion.so/6bade2c6a5f4479f82a4e67eafcebb3a]
"""
# 读取文件内容
def read_file(filename):
    with open(os_path.join(this_directory, filename), encoding='utf-8') as f:
        long_description = f.read()
    return long_description

# 获取依赖
def read_requirements(filename):
    return [line.strip() for line in read_file(filename).splitlines()
            if not line.startswith('#')]
# long_description="""

# 这里是说明
# 一个创建库的demo
# http://www.terrychan.org/python_libs_demo/
# """

long_description=read_file("README.md")
setup(
    name='tkitLogger', #修改包名字
    version='0.0.0.2',
    description='Terry toolkit tkitLogger',
    author='Terry Chan',
    author_email='napoler2008@gmail.com',
    url='http://www.terrychan.org/tkitLogger/',
    # install_requires=read_requirements('requirements.txt'),  # 指定需要安装的依赖
    long_description=long_description,
    long_description_content_type="text/markdown",
    # install_requires=[
    #     # 'beautifulsoup4==4.7.1',


    # ],
    packages=['tkitLogger'])

"""
pip freeze > requirements.txt

python3 setup.py sdist
#python3 setup.py install
python3 setup.py sdist upload
"""